==> estateplat-common-1.2.4-20210720.054444-817-sources.jar: cn/gtmap/estateplat/model/server/core/GdFwsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * .
 * <p/>
 * 房屋所有权
 *
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-4-19
 */
@Table(name = "GD_FWSYQ")
public class GdFwsyq implements Serializable {
    @Id
    private String qlid;
    private String fczh;
    private Integer iszx;
    private String djlx;
    private String djyy;
    private String proid;

    private String fj;
    private Date gxrq;
    private String zslx;
    private String cjrid;//创建人ID
    private String yqzh;//原权证号
    private String bz;//备注

    //增加冗余字段
    private String qlr;//权利人
    private String zl;//坐落
    private String qlrzjzl;//权利人证件种类
    private String qlrzjh;//权利人证件号
    private String bdcdybh;//不动产单元编号
    private String sfcc; //是否拆除
    private String dah; //档案号
    private String fczhfwbh;//房产证号房屋编号
    private String cfqqlid;//拆分前权利ID
    private Integer sfxmndz;//项目内多幢标识
    private Integer cxzt;//撤销状态 1：已撤销,0或空：未撤销
    private String slbh;//受理编号
    private String zxfs;//注销方式  0或空为流程注销 1为手动注销
    private String bazt;//备案状态 0：撤销 1：备案
    private String zjdsjlx;//宅基地数据类型(gy:国有,jt:集体)
    private String fbczhbbh;//分别持证合并编号

    public String getZxfs() {
        return zxfs;
    }

    public void setZxfs(String zxfs) {
        this.zxfs = zxfs;
    }

    public String getSlbh() {
        return slbh;
    }

    public void setSlbh(String slbh) {
        this.slbh = slbh;
    }

    public Integer getCxzt() {
        return cxzt;
    }

    public void setCxzt(Integer cxzt) {
        this.cxzt = cxzt;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getQlrzjzl() {
        return qlrzjzl;
    }

    public void setQlrzjzl(String qlrzjzl) {
        this.qlrzjzl = qlrzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }


    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/6/25,
     * @description
     */
    private Double dytdmj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/6/25
     * @description 分摊土地面积，用于没有关联土地证或土地证书上分摊土地面积不准确的情况
     */
    private Double fttdmj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/6/25
     * @description 土地使用权面积，记录既有独用又有分摊的情况
     */
    private Double tdsyqmj;

    private String tdqsxz;//土地权属性质
    private String tdyt;//土地用途
    private Date tdsyksrq;//土地使用权开始日期
    private Date tdsyjsrq;//土地使用权结束日期
    private String tdsyqlx;//土地使用权类型
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/8/3
     * @description 档案业务号，用于挂接过渡房产登记数据的档案材料信息
     */
    private String daywh;
    private Date djsj;//登记时间
    private String dbr;//登薄人
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号

    private String qllx;
    private String fwsx;//房屋属性
    private String zxdaywh;//注销档案业务
    private String cqzhjc;//产权证号简称

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }


    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    private Date lzrq;//领证日期

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getZslx() {
        return zslx;
    }

    public void setZslx(String zslx) {
        this.zslx = zslx;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getFczh() {
        return fczh;
    }

    public void setFczh(String fczh) {
        this.fczh = fczh;
    }


    public Integer getIszx() {
        return iszx;
    }

    public void setIszx(Integer iszx) {
        this.iszx = iszx;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public Date getLzrq() {
        return lzrq;
    }

    public void setLzrq(Date lzrq) {
        this.lzrq = lzrq;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getTdsyqmj() {
        return tdsyqmj;
    }

    public void setTdsyqmj(Double tdsyqmj) {
        this.tdsyqmj = tdsyqmj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public String getTdqsxz() {
        return tdqsxz;
    }

    public void setTdqsxz(String tdqsxz) {
        this.tdqsxz = tdqsxz;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public Date getTdsyksrq() {
        return tdsyksrq;
    }

    public void setTdsyksrq(Date tdsyksrq) {
        this.tdsyksrq = tdsyksrq;
    }

    public Date getTdsyjsrq() {
        return tdsyjsrq;
    }

    public void setTdsyjsrq(Date tdsyjsrq) {
        this.tdsyjsrq = tdsyjsrq;
    }

    public String getTdsyqlx() {
        return tdsyqlx;
    }

    public void setTdsyqlx(String tdsyqlx) {
        this.tdsyqlx = tdsyqlx;
    }

    public String getDaywh() {
        return daywh;
    }

    public void setDaywh(String daywh) {
        this.daywh = daywh;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getFwsx() {
        return fwsx;
    }

    public void setFwsx(String fwsx) {
        this.fwsx = fwsx;
    }

    public String getZxdaywh() {
        return zxdaywh;
    }

    public void setZxdaywh(String zxdaywh) {
        this.zxdaywh = zxdaywh;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public String getSfcc() {
        return sfcc;
    }

    public void setSfcc(String sfcc) {
        this.sfcc = sfcc;
    }

    public String getDah() {
        return dah;
    }

    public void setDah(String dah) {
        this.dah = dah;
    }

    public String getCqzhjc() {
        return cqzhjc;
    }

    public void setCqzhjc(String cqzhjc) {
        this.cqzhjc = cqzhjc;
    }

    public String getFczhfwbh() {
        return fczhfwbh;
    }

    public void setFczhfwbh(String fczhfwbh) {
        this.fczhfwbh = fczhfwbh;
    }

    public String getCfqqlid() {
        return cfqqlid;
    }

    public void setCfqqlid(String cfqqlid) {
        this.cfqqlid = cfqqlid;
    }

    public Integer getSfxmndz() {
        return sfxmndz;
    }

    public void setSfxmndz(Integer sfxmndz) {
        this.sfxmndz = sfxmndz;
    }

    public String getBazt() {
        return bazt;
    }

    public void setBazt(String bazt) {
        this.bazt = bazt;
    }

    public String getZjdsjlx() {
        return zjdsjlx;
    }

    public void setZjdsjlx(String zjdsjlx) {
        this.zjdsjlx = zjdsjlx;
    }

    public String getFbczhbbh() {
        return fbczhbbh;
    }

    public void setFbczhbbh(String fbczhbbh) {
        this.fbczhbbh = fbczhbbh;
    }
}

==> estateplat-common-1.2.4-20210824.022530-851-sources.jar: cn/gtmap/estateplat/model/server/core/GdFwsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * .
 * <p/>
 * 房屋所有权
 *
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-4-19
 */
@Table(name = "GD_FWSYQ")
public class GdFwsyq implements Serializable {
    @Id
    private String qlid;
    private String fczh;
    private Integer iszx;
    private String djlx;
    private String djyy;
    private String proid;

    private String fj;
    private Date gxrq;
    private String zslx;
    private String cjrid;//创建人ID
    private String yqzh;//原权证号
    private String bz;//备注

    //增加冗余字段
    private String qlr;//权利人
    private String zl;//坐落
    private String qlrzjzl;//权利人证件种类
    private String qlrzjh;//权利人证件号
    private String bdcdybh;//不动产单元编号
    private String sfcc; //是否拆除
    private String dah; //档案号
    private String fczhfwbh;//房产证号房屋编号
    private String cfqqlid;//拆分前权利ID
    private Integer sfxmndz;//项目内多幢标识
    private Integer cxzt;//撤销状态 1：已撤销,0或空：未撤销
    private String slbh;//受理编号
    private String zxfs;//注销方式  0或空为流程注销 1为手动注销
    private String bazt;//备案状态 0：撤销 1：备案
    private String zjdsjlx;//宅基地数据类型(gy:国有,jt:集体)
    private String fbczhbbh;//分别持证合并编号

    /**
     * 权利其他状况
     */
    private String qlqtzk;

    public String getZxfs() {
        return zxfs;
    }

    public void setZxfs(String zxfs) {
        this.zxfs = zxfs;
    }

    public String getSlbh() {
        return slbh;
    }

    public void setSlbh(String slbh) {
        this.slbh = slbh;
    }

    public Integer getCxzt() {
        return cxzt;
    }

    public void setCxzt(Integer cxzt) {
        this.cxzt = cxzt;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getQlrzjzl() {
        return qlrzjzl;
    }

    public void setQlrzjzl(String qlrzjzl) {
        this.qlrzjzl = qlrzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }


    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/6/25,
     * @description
     */
    private Double dytdmj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/6/25
     * @description 分摊土地面积，用于没有关联土地证或土地证书上分摊土地面积不准确的情况
     */
    private Double fttdmj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/6/25
     * @description 土地使用权面积，记录既有独用又有分摊的情况
     */
    private Double tdsyqmj;

    private String tdqsxz;//土地权属性质
    private String tdyt;//土地用途
    private Date tdsyksrq;//土地使用权开始日期
    private Date tdsyjsrq;//土地使用权结束日期
    private String tdsyqlx;//土地使用权类型
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/8/3
     * @description 档案业务号，用于挂接过渡房产登记数据的档案材料信息
     */
    private String daywh;
    private Date djsj;//登记时间
    private String dbr;//登薄人
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号

    private String qllx;
    private String fwsx;//房屋属性
    private String zxdaywh;//注销档案业务
    private String cqzhjc;//产权证号简称

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }


    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    private Date lzrq;//领证日期

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getZslx() {
        return zslx;
    }

    public void setZslx(String zslx) {
        this.zslx = zslx;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getFczh() {
        return fczh;
    }

    public void setFczh(String fczh) {
        this.fczh = fczh;
    }


    public Integer getIszx() {
        return iszx;
    }

    public void setIszx(Integer iszx) {
        this.iszx = iszx;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public Date getLzrq() {
        return lzrq;
    }

    public void setLzrq(Date lzrq) {
        this.lzrq = lzrq;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getTdsyqmj() {
        return tdsyqmj;
    }

    public void setTdsyqmj(Double tdsyqmj) {
        this.tdsyqmj = tdsyqmj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public String getTdqsxz() {
        return tdqsxz;
    }

    public void setTdqsxz(String tdqsxz) {
        this.tdqsxz = tdqsxz;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public Date getTdsyksrq() {
        return tdsyksrq;
    }

    public void setTdsyksrq(Date tdsyksrq) {
        this.tdsyksrq = tdsyksrq;
    }

    public Date getTdsyjsrq() {
        return tdsyjsrq;
    }

    public void setTdsyjsrq(Date tdsyjsrq) {
        this.tdsyjsrq = tdsyjsrq;
    }

    public String getTdsyqlx() {
        return tdsyqlx;
    }

    public void setTdsyqlx(String tdsyqlx) {
        this.tdsyqlx = tdsyqlx;
    }

    public String getDaywh() {
        return daywh;
    }

    public void setDaywh(String daywh) {
        this.daywh = daywh;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getFwsx() {
        return fwsx;
    }

    public void setFwsx(String fwsx) {
        this.fwsx = fwsx;
    }

    public String getZxdaywh() {
        return zxdaywh;
    }

    public void setZxdaywh(String zxdaywh) {
        this.zxdaywh = zxdaywh;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public String getSfcc() {
        return sfcc;
    }

    public void setSfcc(String sfcc) {
        this.sfcc = sfcc;
    }

    public String getDah() {
        return dah;
    }

    public void setDah(String dah) {
        this.dah = dah;
    }

    public String getCqzhjc() {
        return cqzhjc;
    }

    public void setCqzhjc(String cqzhjc) {
        this.cqzhjc = cqzhjc;
    }

    public String getFczhfwbh() {
        return fczhfwbh;
    }

    public void setFczhfwbh(String fczhfwbh) {
        this.fczhfwbh = fczhfwbh;
    }

    public String getCfqqlid() {
        return cfqqlid;
    }

    public void setCfqqlid(String cfqqlid) {
        this.cfqqlid = cfqqlid;
    }

    public Integer getSfxmndz() {
        return sfxmndz;
    }

    public void setSfxmndz(Integer sfxmndz) {
        this.sfxmndz = sfxmndz;
    }

    public String getBazt() {
        return bazt;
    }

    public void setBazt(String bazt) {
        this.bazt = bazt;
    }

    public String getZjdsjlx() {
        return zjdsjlx;
    }

    public void setZjdsjlx(String zjdsjlx) {
        this.zjdsjlx = zjdsjlx;
    }

    public String getFbczhbbh() {
        return fbczhbbh;
    }

    public void setFbczhbbh(String fbczhbbh) {
        this.fbczhbbh = fbczhbbh;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }
}
